@@ -13,7 +13,6 @@ def log_func(msg, new_line=True, clear=False):
 
 @click.command()
 @project_code_option(
-    help="Not required when --no-send-to-flow option is set",
     required=False,
 )
 @click.option(
@@ -46,10 +45,32 @@ def log_func(msg, new_line=True, clear=False):
     default=True,
     show_default=True,
     required=False,
+    hidden=True,
     help="""Enable or disable the ability of send analysis result
     reports to flow. When --send-to-flow option is set the --project-code
     option is required"""
 )
+@click.option(
+    "--deploy-id",
+    default=None,
+    required=False,
+    hidden=True,
+    envvar="FLOW_DEPLOY_ID"
+)
+@click.option(
+    "--sastbox-registry",
+    default="",
+    required=False,
+    hidden=True,
+    envvar="FLOW_SASTBOX_REGISTRY"
+)
+@click.option(
+    "--sastbox-repository-name",
+    default="",
+    required=False,
+    hidden=True,
+    envvar="FLOW_SASTBOX_REPOSITORY_NAME"
+)
 @click.option(
     "--sastbox-tag",
     default=SASTBox.DEFAULT_TAG,
@@ -57,11 +78,20 @@ def log_func(msg, new_line=True, clear=False):
     hidden=True,
     envvar="FLOW_SASTBOX_TAG"
 )
+@click.option(
+    "--sastbox-skip-login/--sastbox-no-skip-login",
+    default=False,
+    required=False,
+    hidden=True,
+    envvar="FLOW_SASTBOX_SKIP_LOGIN"
+)
 @help_option
 @pass_flow_context
 def run(
     flow_context, project_code, end_commit,
-    start_commit, repository_dir, send_to_flow, sastbox_tag
+    start_commit, repository_dir, send_to_flow,
+    deploy_id, sastbox_registry, sastbox_repository_name,
+    sastbox_tag, sastbox_skip_login
 ):
     '''
       This command will perform SAST analysis at the source code. The analysis
@@ -77,13 +107,19 @@ def run(
         start_commit,
         repository_dir,
         send_to_flow,
-        sastbox_tag
+        deploy_id,
+        sastbox_registry,
+        sastbox_repository_name,
+        sastbox_tag,
+        sastbox_skip_login,
     )
 
 
 def perform_command(
     flow_context, project_code, end_commit,
-    start_commit, repository_dir, send_to_flow, sastbox_tag
+    start_commit, repository_dir, send_to_flow,
+    deploy_id, sastbox_registry, sastbox_repository_name,
+    sastbox_tag, sastbox_skip_login
 ):
     if send_to_flow and not project_code:
         raise click.MissingParameter(
@@ -104,10 +140,16 @@ def perform_command(
         )
 
         flow = flow_context.create_flow_api_client()
-        token = flow.docker_registry.get_sast_token()
-        sastbox = SASTBox(sastbox_tag)
-        log_func('Checking SASTBox authorization...')
-        sastbox.login(token)
+        sastbox = SASTBox(
+            registry=sastbox_registry,
+            repository_name=sastbox_repository_name,
+            tag=sastbox_tag,
+        )
+
+        if not sastbox_skip_login:
+            log_func('Checking SASTBox authorization...')
+            token = flow.docker_registry.get_sast_token()
+            sastbox.login(token)
 
         pull_progress_bar = click.progressbar(
             length=sastbox.size,
@@ -149,7 +191,8 @@ def perform_command(
                         project_code,
                         commit_refs,
                         report_file,
-                        default_report_type=default_report_type
+                        default_report_type=default_report_type,
+                        deploy_id=deploy_id,
                     )
 
                     report_file.close()
@@ -176,21 +219,6 @@ Examples:
       $ export FLOW_API_KEY='your-api-key'
       $ export FLOW_PROJECT_CODE='your-project-code'
       $ {command} --start-commit "$(git rev-parse HEAD~5)" --end-commit "$(git rev-parse HEAD)"
-
-  \b
-  2 - Not Reporting the results to flow api:
-    Note that when not reporting the results the FLOW_PROJECT_CODE is not necessary.
-
-    \b
-    2.1 - Running an analysis at all commit range:
-      $ export FLOW_API_KEY='your-api-key'
-      $ {command} --no-send-to-flow
-
-    \b
-    2.2 - Running an analysis at specific commit range:
-      $ export FLOW_API_KEY='your-api-key'
-      $ {command} --no-send-to-flow --start-commit "$(git rev-parse HEAD~5)" --end-commit "$(git rev-parse HEAD)"
-
 '''  # noqa: E501
 
 SHORT_HELP = "Perform SAST analysis"
